/****************************************************************************
** Meta object code from reading C++ file 'sizing.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../sizing.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'sizing.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SizingE_t {};
} // unnamed namespace

template <> constexpr inline auto Sizing::qt_create_metaobjectdata<qt_meta_tag_ZN6SizingE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Sizing",
        "mmScaleFactorChanged",
        "",
        "dpScaleFactorChanged",
        "densitieChanged",
        "screenDPIChanged",
        "physicalDotsPerInchChanged",
        "dpi",
        "physicalSizeChanged",
        "QSizeF",
        "size",
        "dp",
        "value",
        "mm",
        "mmScaleFactor",
        "dpScaleFactor",
        "densitie",
        "Densitie"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'mmScaleFactorChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dpScaleFactorChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'densitieChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'screenDPIChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'physicalDotsPerInchChanged'
        QtMocHelpers::SlotData<void(qreal)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 7 },
        }}),
        // Slot 'physicalSizeChanged'
        QtMocHelpers::SlotData<void(const QSizeF &)>(8, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Method 'dp'
        QtMocHelpers::MethodData<float(float)>(11, 2, QMC::AccessPublic, QMetaType::Float, {{
            { QMetaType::Float, 12 },
        }}),
        // Method 'mm'
        QtMocHelpers::MethodData<float(float)>(13, 2, QMC::AccessPublic, QMetaType::Float, {{
            { QMetaType::Float, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mmScaleFactor'
        QtMocHelpers::PropertyData<float>(14, QMetaType::Float, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'dpScaleFactor'
        QtMocHelpers::PropertyData<float>(15, QMetaType::Float, QMC::DefaultPropertyFlags, 1),
        // property 'densitie'
        QtMocHelpers::PropertyData<enum Densitie>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Sizing, qt_meta_tag_ZN6SizingE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Sizing::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SizingE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SizingE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SizingE_t>.metaTypes,
    nullptr
} };

void Sizing::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sizing *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->mmScaleFactorChanged(); break;
        case 1: _t->dpScaleFactorChanged(); break;
        case 2: _t->densitieChanged(); break;
        case 3: _t->screenDPIChanged(); break;
        case 4: _t->physicalDotsPerInchChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 5: _t->physicalSizeChanged((*reinterpret_cast<std::add_pointer_t<QSizeF>>(_a[1]))); break;
        case 6: { float _r = _t->dp((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])));
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        case 7: { float _r = _t->mm((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])));
            if (_a[0]) *reinterpret_cast<float*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Sizing::*)()>(_a, &Sizing::mmScaleFactorChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sizing::*)()>(_a, &Sizing::dpScaleFactorChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sizing::*)()>(_a, &Sizing::densitieChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sizing::*)()>(_a, &Sizing::screenDPIChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->mmScaleFactor(); break;
        case 1: *reinterpret_cast<float*>(_v) = _t->dpScaleFactor(); break;
        case 2: *reinterpret_cast<enum Densitie*>(_v) = _t->densitie(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setMmScaleFactor(*reinterpret_cast<float*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Sizing::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Sizing::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SizingE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Sizing::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void Sizing::mmScaleFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Sizing::dpScaleFactorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Sizing::densitieChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Sizing::screenDPIChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
