/****************************************************************************
** Meta object code from reading C++ file 'theme.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../theme.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'theme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN5ThemeE_t {};
} // unnamed namespace

template <> constexpr inline auto Theme::qt_create_metaobjectdata<qt_meta_tag_ZN5ThemeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Theme",
        "themeUpdate",
        "",
        "itemWidthLargeChanged",
        "itemWidthMediumChanged",
        "itemWidthSmallChanged",
        "itemWidthExtraSmallChanged",
        "itemHeightHugeChanged",
        "itemHeightExtraLargeChanged",
        "itemHeightLargeChanged",
        "itemHeightMediumChanged",
        "itemHeightSmallChanged",
        "itemHeightExtraSmallChanged",
        "itemSpacingHugeChanged",
        "itemSpacingLargeChanged",
        "itemSpacingMediumChanged",
        "itemSpacingSmallChanged",
        "itemSpacingExtraSmallChanged",
        "fontSizeExtraLargeChanged",
        "fontSizeLargeChanged",
        "fontSizeMediumChanged",
        "fontSizeSmallChanged",
        "fontSizeTinyChanged",
        "fontWeightLargeChanged",
        "fontWeightMediumChanged",
        "fontFamilyChanged",
        "accentColorChanged",
        "fillColorChanged",
        "fillDarkColorChanged",
        "textColorChanged",
        "backgroundColorChanged",
        "backgroundAccentColorChanged",
        "iconSizeLauncherChanged",
        "desktopModeChanged",
        "itemWidthExtraLargeChanged",
        "desktopModeValueChanged",
        "themeValueChanged",
        "loadTheme",
        "fileName",
        "iconSizeLauncher",
        "itemWidthExtraLarge",
        "itemWidthLarge",
        "itemWidthMedium",
        "itemWidthSmall",
        "itemWidthExtraSmall",
        "itemHeightHuge",
        "itemHeightExtraLarge",
        "itemHeightLarge",
        "itemHeightMedium",
        "itemHeightSmall",
        "itemHeightExtraSmall",
        "itemSpacingHuge",
        "itemSpacingLarge",
        "itemSpacingMedium",
        "itemSpacingSmall",
        "itemSpacingExtraSmall",
        "fontSizeExtraLarge",
        "fontSizeLarge",
        "fontSizeMedium",
        "fontSizeSmall",
        "fontSizeTiny",
        "fontWeightLarge",
        "fontWeightMedium",
        "fontFamily",
        "accentColor",
        "fillColor",
        "fillDarkColor",
        "textColor",
        "backgroundColor",
        "backgroundAccentColor",
        "desktopMode",
        "themePath"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'themeUpdate'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemWidthLargeChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemWidthMediumChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemWidthSmallChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemWidthExtraSmallChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemHeightHugeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemHeightExtraLargeChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemHeightLargeChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemHeightMediumChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemHeightSmallChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemHeightExtraSmallChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemSpacingHugeChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemSpacingLargeChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemSpacingMediumChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemSpacingSmallChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemSpacingExtraSmallChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeExtraLargeChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeLargeChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeMediumChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeSmallChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontSizeTinyChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontWeightLargeChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontWeightMediumChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fontFamilyChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'accentColorChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillColorChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fillDarkColorChanged'
        QtMocHelpers::SignalData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'textColorChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundColorChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'backgroundAccentColorChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconSizeLauncherChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'desktopModeChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'itemWidthExtraLargeChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'desktopModeValueChanged'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'themeValueChanged'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'loadTheme'
        QtMocHelpers::MethodData<bool(QString)>(37, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 38 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'iconSizeLauncher'
        QtMocHelpers::PropertyData<qreal>(39, QMetaType::QReal, QMC::DefaultPropertyFlags, 30),
        // property 'itemWidthExtraLarge'
        QtMocHelpers::PropertyData<qreal>(40, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'itemWidthLarge'
        QtMocHelpers::PropertyData<qreal>(41, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'itemWidthMedium'
        QtMocHelpers::PropertyData<qreal>(42, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'itemWidthSmall'
        QtMocHelpers::PropertyData<qreal>(43, QMetaType::QReal, QMC::DefaultPropertyFlags, 3),
        // property 'itemWidthExtraSmall'
        QtMocHelpers::PropertyData<qreal>(44, QMetaType::QReal, QMC::DefaultPropertyFlags, 4),
        // property 'itemHeightHuge'
        QtMocHelpers::PropertyData<qreal>(45, QMetaType::QReal, QMC::DefaultPropertyFlags, 5),
        // property 'itemHeightExtraLarge'
        QtMocHelpers::PropertyData<qreal>(46, QMetaType::QReal, QMC::DefaultPropertyFlags, 6),
        // property 'itemHeightLarge'
        QtMocHelpers::PropertyData<qreal>(47, QMetaType::QReal, QMC::DefaultPropertyFlags, 7),
        // property 'itemHeightMedium'
        QtMocHelpers::PropertyData<qreal>(48, QMetaType::QReal, QMC::DefaultPropertyFlags, 8),
        // property 'itemHeightSmall'
        QtMocHelpers::PropertyData<qreal>(49, QMetaType::QReal, QMC::DefaultPropertyFlags, 9),
        // property 'itemHeightExtraSmall'
        QtMocHelpers::PropertyData<qreal>(50, QMetaType::QReal, QMC::DefaultPropertyFlags, 10),
        // property 'itemSpacingHuge'
        QtMocHelpers::PropertyData<qreal>(51, QMetaType::QReal, QMC::DefaultPropertyFlags, 11),
        // property 'itemSpacingLarge'
        QtMocHelpers::PropertyData<qreal>(52, QMetaType::QReal, QMC::DefaultPropertyFlags, 12),
        // property 'itemSpacingMedium'
        QtMocHelpers::PropertyData<qreal>(53, QMetaType::QReal, QMC::DefaultPropertyFlags, 13),
        // property 'itemSpacingSmall'
        QtMocHelpers::PropertyData<qreal>(54, QMetaType::QReal, QMC::DefaultPropertyFlags, 14),
        // property 'itemSpacingExtraSmall'
        QtMocHelpers::PropertyData<qreal>(55, QMetaType::QReal, QMC::DefaultPropertyFlags, 15),
        // property 'fontSizeExtraLarge'
        QtMocHelpers::PropertyData<int>(56, QMetaType::Int, QMC::DefaultPropertyFlags, 16),
        // property 'fontSizeLarge'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags, 17),
        // property 'fontSizeMedium'
        QtMocHelpers::PropertyData<int>(58, QMetaType::Int, QMC::DefaultPropertyFlags, 18),
        // property 'fontSizeSmall'
        QtMocHelpers::PropertyData<int>(59, QMetaType::Int, QMC::DefaultPropertyFlags, 19),
        // property 'fontSizeTiny'
        QtMocHelpers::PropertyData<int>(60, QMetaType::Int, QMC::DefaultPropertyFlags, 20),
        // property 'fontWeightLarge'
        QtMocHelpers::PropertyData<int>(61, QMetaType::Int, QMC::DefaultPropertyFlags, 21),
        // property 'fontWeightMedium'
        QtMocHelpers::PropertyData<int>(62, QMetaType::Int, QMC::DefaultPropertyFlags, 22),
        // property 'fontFamily'
        QtMocHelpers::PropertyData<QString>(63, QMetaType::QString, QMC::DefaultPropertyFlags, 23),
        // property 'accentColor'
        QtMocHelpers::PropertyData<QString>(64, QMetaType::QString, QMC::DefaultPropertyFlags, 24),
        // property 'fillColor'
        QtMocHelpers::PropertyData<QString>(65, QMetaType::QString, QMC::DefaultPropertyFlags, 25),
        // property 'fillDarkColor'
        QtMocHelpers::PropertyData<QString>(66, QMetaType::QString, QMC::DefaultPropertyFlags, 26),
        // property 'textColor'
        QtMocHelpers::PropertyData<QString>(67, QMetaType::QString, QMC::DefaultPropertyFlags, 27),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QString>(68, QMetaType::QString, QMC::DefaultPropertyFlags, 28),
        // property 'backgroundAccentColor'
        QtMocHelpers::PropertyData<QString>(69, QMetaType::QString, QMC::DefaultPropertyFlags, 29),
        // property 'desktopMode'
        QtMocHelpers::PropertyData<bool>(70, QMetaType::Bool, QMC::DefaultPropertyFlags, 31),
        // property 'themePath'
        QtMocHelpers::PropertyData<QString>(71, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Theme, qt_meta_tag_ZN5ThemeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Theme::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5ThemeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5ThemeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN5ThemeE_t>.metaTypes,
    nullptr
} };

void Theme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Theme *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->themeUpdate(); break;
        case 1: _t->itemWidthLargeChanged(); break;
        case 2: _t->itemWidthMediumChanged(); break;
        case 3: _t->itemWidthSmallChanged(); break;
        case 4: _t->itemWidthExtraSmallChanged(); break;
        case 5: _t->itemHeightHugeChanged(); break;
        case 6: _t->itemHeightExtraLargeChanged(); break;
        case 7: _t->itemHeightLargeChanged(); break;
        case 8: _t->itemHeightMediumChanged(); break;
        case 9: _t->itemHeightSmallChanged(); break;
        case 10: _t->itemHeightExtraSmallChanged(); break;
        case 11: _t->itemSpacingHugeChanged(); break;
        case 12: _t->itemSpacingLargeChanged(); break;
        case 13: _t->itemSpacingMediumChanged(); break;
        case 14: _t->itemSpacingSmallChanged(); break;
        case 15: _t->itemSpacingExtraSmallChanged(); break;
        case 16: _t->fontSizeExtraLargeChanged(); break;
        case 17: _t->fontSizeLargeChanged(); break;
        case 18: _t->fontSizeMediumChanged(); break;
        case 19: _t->fontSizeSmallChanged(); break;
        case 20: _t->fontSizeTinyChanged(); break;
        case 21: _t->fontWeightLargeChanged(); break;
        case 22: _t->fontWeightMediumChanged(); break;
        case 23: _t->fontFamilyChanged(); break;
        case 24: _t->accentColorChanged(); break;
        case 25: _t->fillColorChanged(); break;
        case 26: _t->fillDarkColorChanged(); break;
        case 27: _t->textColorChanged(); break;
        case 28: _t->backgroundColorChanged(); break;
        case 29: _t->backgroundAccentColorChanged(); break;
        case 30: _t->iconSizeLauncherChanged(); break;
        case 31: _t->desktopModeChanged(); break;
        case 32: _t->itemWidthExtraLargeChanged(); break;
        case 33: _t->desktopModeValueChanged(); break;
        case 34: _t->themeValueChanged(); break;
        case 35: { bool _r = _t->loadTheme((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::themeUpdate, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemWidthLargeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemWidthMediumChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemWidthSmallChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemWidthExtraSmallChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemHeightHugeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemHeightExtraLargeChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemHeightLargeChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemHeightMediumChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemHeightSmallChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemHeightExtraSmallChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemSpacingHugeChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemSpacingLargeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemSpacingMediumChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemSpacingSmallChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemSpacingExtraSmallChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontSizeExtraLargeChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontSizeLargeChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontSizeMediumChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontSizeSmallChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontSizeTinyChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontWeightLargeChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontWeightMediumChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fontFamilyChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::accentColorChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fillColorChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::fillDarkColorChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::textColorChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::backgroundColorChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::backgroundAccentColorChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::iconSizeLauncherChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::desktopModeChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Theme::*)()>(_a, &Theme::itemWidthExtraLargeChanged, 32))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qreal*>(_v) = _t->iconSizeLauncher(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->itemWidthExtraLarge(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->itemWidthLarge(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->itemWidthMedium(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->itemWidthSmall(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->itemWidthExtraSmall(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->itemHeightHuge(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->itemHeightExtraLarge(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->itemHeightLarge(); break;
        case 9: *reinterpret_cast<qreal*>(_v) = _t->itemHeightMedium(); break;
        case 10: *reinterpret_cast<qreal*>(_v) = _t->itemHeightSmall(); break;
        case 11: *reinterpret_cast<qreal*>(_v) = _t->itemHeightExtraSmall(); break;
        case 12: *reinterpret_cast<qreal*>(_v) = _t->itemSpacingHuge(); break;
        case 13: *reinterpret_cast<qreal*>(_v) = _t->itemSpacingLarge(); break;
        case 14: *reinterpret_cast<qreal*>(_v) = _t->itemSpacingMedium(); break;
        case 15: *reinterpret_cast<qreal*>(_v) = _t->itemSpacingSmall(); break;
        case 16: *reinterpret_cast<qreal*>(_v) = _t->itemSpacingExtraSmall(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->fontSizeExtraLarge(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->fontSizeLarge(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->fontSizeMedium(); break;
        case 20: *reinterpret_cast<int*>(_v) = _t->fontSizeSmall(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->fontSizeTiny(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->fontWeightLarge(); break;
        case 23: *reinterpret_cast<int*>(_v) = _t->fontWeightMedium(); break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->fontFamily(); break;
        case 25: *reinterpret_cast<QString*>(_v) = _t->accentColor(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->fillColor(); break;
        case 27: *reinterpret_cast<QString*>(_v) = _t->fillDarkColor(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->textColor(); break;
        case 29: *reinterpret_cast<QString*>(_v) = _t->backgroundColor(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->backgroundAccentColor(); break;
        case 31: *reinterpret_cast<bool*>(_v) = _t->desktopMode(); break;
        case 32: *reinterpret_cast<QString*>(_v) = _t->themePath(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setItemWidthExtraLarge(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Theme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Theme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN5ThemeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Theme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 36)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 36;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 36)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 36;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 33;
    }
    return _id;
}

// SIGNAL 0
void Theme::themeUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Theme::itemWidthLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Theme::itemWidthMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Theme::itemWidthSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Theme::itemWidthExtraSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Theme::itemHeightHugeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Theme::itemHeightExtraLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Theme::itemHeightLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Theme::itemHeightMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Theme::itemHeightSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Theme::itemHeightExtraSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Theme::itemSpacingHugeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Theme::itemSpacingLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Theme::itemSpacingMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Theme::itemSpacingSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Theme::itemSpacingExtraSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Theme::fontSizeExtraLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Theme::fontSizeLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Theme::fontSizeMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Theme::fontSizeSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Theme::fontSizeTinyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Theme::fontWeightLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Theme::fontWeightMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Theme::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Theme::accentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Theme::fillColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Theme::fillDarkColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Theme::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Theme::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Theme::backgroundAccentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void Theme::iconSizeLauncherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void Theme::desktopModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void Theme::itemWidthExtraLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}
QT_WARNING_POP
