#include <QtQml/qqmlprivate.h>
#include <QtCore/qdir.h>
#include <QtCore/qurl.h>
#include <QtCore/qhash.h>
#include <QtCore/qstring.h>

namespace QmlCacheGeneratedCode {
namespace _0x5f_Nemo_Controls_qml_ActionButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ApplicationWindow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Button_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ButtonRow_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Checkbox_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_DatePicker_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ErrorStackPage_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_GlacierRollerItem_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_GlacierRoller_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Header_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_HeaderToolsIndicator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_HeaderToolsLayout_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_IconButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Label_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ListViewItemWithActions_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ListView_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_NemoIcon_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Page_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ProgressBar_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ScrollDecorator_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Slider_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_Spinner_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_TextField_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_TabButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_TimePicker_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}
namespace _0x5f_Nemo_Controls_qml_ToolButton_qml { 
    extern const unsigned char qmlData[];
    extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
    const QQmlPrivate::CachedQmlUnit unit = {
        reinterpret_cast<const QV4::CompiledData::Unit*>(&qmlData), &aotBuiltFunctions[0], nullptr
    };
}

}
namespace {
struct Registry {
    Registry();
    ~Registry();
    QHash<QString, const QQmlPrivate::CachedQmlUnit*> resourcePathToCachedUnit;
    static const QQmlPrivate::CachedQmlUnit *lookupCachedUnit(const QUrl &url);
};

Q_GLOBAL_STATIC(Registry, unitRegistry)


Registry::Registry() {
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ActionButton.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ActionButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ApplicationWindow.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ApplicationWindow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Button.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Button_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ButtonRow.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ButtonRow_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Checkbox.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Checkbox_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/DatePicker.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_DatePicker_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ErrorStackPage.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ErrorStackPage_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/GlacierRollerItem.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_GlacierRollerItem_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/GlacierRoller.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_GlacierRoller_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Header.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Header_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/HeaderToolsIndicator.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_HeaderToolsIndicator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/HeaderToolsLayout.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_HeaderToolsLayout_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/IconButton.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_IconButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Label.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Label_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ListViewItemWithActions.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ListViewItemWithActions_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ListView.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ListView_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/NemoIcon.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_NemoIcon_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Page.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Page_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ProgressBar.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ProgressBar_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ScrollDecorator.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ScrollDecorator_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Slider.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Slider_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/Spinner.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_Spinner_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/TextField.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_TextField_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/TabButton.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_TabButton_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/TimePicker.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_TimePicker_qml::unit);
    resourcePathToCachedUnit.insert(QStringLiteral("/Nemo/Controls/qml/ToolButton.qml"), &QmlCacheGeneratedCode::_0x5f_Nemo_Controls_qml_ToolButton_qml::unit);
    QQmlPrivate::RegisterQmlUnitCacheHook registration;
    registration.structVersion = 0;
    registration.lookupCachedQmlUnit = &lookupCachedUnit;
    QQmlPrivate::qmlregister(QQmlPrivate::QmlUnitCacheHookRegistration, &registration);
}

Registry::~Registry() {
    QQmlPrivate::qmlunregister(QQmlPrivate::QmlUnitCacheHookRegistration, quintptr(&lookupCachedUnit));
}

const QQmlPrivate::CachedQmlUnit *Registry::lookupCachedUnit(const QUrl &url) {
    if (url.scheme() != QLatin1String("qrc"))
        return nullptr;
    QString resourcePath = QDir::cleanPath(url.path());
    if (resourcePath.isEmpty())
        return nullptr;
    if (!resourcePath.startsWith(QLatin1Char('/')))
        resourcePath.prepend(QLatin1Char('/'));
    return unitRegistry()->resourcePathToCachedUnit.value(resourcePath, nullptr);
}
}
int QT_MANGLE_NAMESPACE(qInitResources_qmlcache_nemocontrolsplugin)() {
    ::unitRegistry();
    return 1;
}
Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_qmlcache_nemocontrolsplugin))
int QT_MANGLE_NAMESPACE(qCleanupResources_qmlcache_nemocontrolsplugin)() {
    return 1;
}
