/****************************************************************************
** Meta object code from reading C++ file 'filteringmousearea.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../filteringmousearea.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'filteringmousearea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18FilteringMouseAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto FilteringMouseArea::qt_create_metaobjectdata<qt_meta_tag_ZN18FilteringMouseAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FilteringMouseArea",
        "pressedChanged",
        "",
        "pressed",
        "QPointF",
        "pos",
        "released",
        "positionChanged",
        "pressPosChanged",
        "deltaPosChanged",
        "swipingXChanged",
        "swipingYChanged",
        "swipingThresholdChanged",
        "grabMouseEvents",
        "ungrabMouseEvents",
        "pressPos",
        "deltaPos",
        "swipingX",
        "swipingY",
        "swipingThreshold"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pressedChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pressed'
        QtMocHelpers::SignalData<void(const QPointF &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'released'
        QtMocHelpers::SignalData<void(const QPointF &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(const QPointF &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'pressPosChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'deltaPosChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'swipingXChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'swipingYChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'swipingThresholdChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'grabMouseEvents'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ungrabMouseEvents'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pressed'
        QtMocHelpers::PropertyData<bool>(3, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'pressPos'
        QtMocHelpers::PropertyData<QPointF>(15, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
        // property 'deltaPos'
        QtMocHelpers::PropertyData<QPointF>(16, 0x80000000 | 4, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 5),
        // property 'swipingX'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'swipingY'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags, 7),
        // property 'swipingThreshold'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FilteringMouseArea, qt_meta_tag_ZN18FilteringMouseAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FilteringMouseArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FilteringMouseAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FilteringMouseAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18FilteringMouseAreaE_t>.metaTypes,
    nullptr
} };

void FilteringMouseArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FilteringMouseArea *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pressedChanged(); break;
        case 1: _t->pressed((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 2: _t->released((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 3: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1]))); break;
        case 4: _t->pressPosChanged(); break;
        case 5: _t->deltaPosChanged(); break;
        case 6: _t->swipingXChanged(); break;
        case 7: _t->swipingYChanged(); break;
        case 8: _t->swipingThresholdChanged(); break;
        case 9: _t->grabMouseEvents(); break;
        case 10: _t->ungrabMouseEvents(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)()>(_a, &FilteringMouseArea::pressedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)(const QPointF & )>(_a, &FilteringMouseArea::pressed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)(const QPointF & )>(_a, &FilteringMouseArea::released, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)(const QPointF & )>(_a, &FilteringMouseArea::positionChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)()>(_a, &FilteringMouseArea::pressPosChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)()>(_a, &FilteringMouseArea::deltaPosChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)()>(_a, &FilteringMouseArea::swipingXChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)()>(_a, &FilteringMouseArea::swipingYChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FilteringMouseArea::*)()>(_a, &FilteringMouseArea::swipingThresholdChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isPressed(); break;
        case 1: *reinterpret_cast<QPointF*>(_v) = _t->pressPos(); break;
        case 2: *reinterpret_cast<QPointF*>(_v) = _t->deltaPos(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isSwipingX(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isSwipingY(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->swipingThreshold(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setSwipingThreshold(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *FilteringMouseArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FilteringMouseArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18FilteringMouseAreaE_t>.strings))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int FilteringMouseArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void FilteringMouseArea::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void FilteringMouseArea::pressed(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void FilteringMouseArea::released(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void FilteringMouseArea::positionChanged(const QPointF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void FilteringMouseArea::pressPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void FilteringMouseArea::deltaPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void FilteringMouseArea::swipingXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void FilteringMouseArea::swipingYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void FilteringMouseArea::swipingThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
